# AWC METAR Downloader
Download parsed METAR data (real-time and historical) from NOAA sites like Aviation Weather Center and Weather.gov.

[![ci](https://github.com/ai4time/pymetard/actions/workflows/ci.yml/badge.svg)](https://github.com/ai4time/pymetard/actions/workflows/ci.yml)
[![dist](https://github.com/ai4time/pymetard/actions/workflows/dist.yaml/badge.svg)](https://github.com/ai4time/pymetard/actions/workflows/dist.yaml)
